@@ -2,7 +2,8 @@
 
 import inspect
 import mock
-from unittest import TestCase
+import sys
+from unittest import TestCase, skipIf
 from nose.tools import assert_equal, assert_raises
 
 from .parameterized import (
@@ -21,6 +22,7 @@ PYTEST = (runner == "pytest")
 
 SKIP_FLAGS = {
     "generator": UNITTEST,
+    "standalone": UNITTEST,
     # nose2 doesn't run tests on old-style classes under Py2, so don't expect
     # these tests to run under nose2.
     "py2nose2": (PY2 and NOSE2),
@@ -44,7 +46,7 @@ test_params = [
     param("foo2", bar=42),
 ]
 
-expect("generator", [
+expect("standalone", [
     "test_naked_function('foo0', bar=None)",
     "test_naked_function('foo1', bar=None)",
     "test_naked_function('foo2', bar=42)",
@@ -165,12 +167,9 @@ class TestParameterizedExpandWithNoMockPatchForClass(TestCase):
                              (foo, mock_umask._mock_name))
 
     expect([
-        "test_multiple_function_patch_decorator"
-        "(42, 51, 'umask', 'fdopen')",
-        "test_multiple_function_patch_decorator"
-        "('foo0', 'bar0', 'umask', 'fdopen')",
-        "test_multiple_function_patch_decorator"
-        "('foo1', 'bar1', 'umask', 'fdopen')",
+        "test_multiple_function_patch_decorator(42, 51, 'umask', 'fdopen')",
+        "test_multiple_function_patch_decorator('foo0', 'bar0', 'umask', 'fdopen')",
+        "test_multiple_function_patch_decorator('foo1', 'bar1', 'umask', 'fdopen')",
     ])
 
     @parameterized.expand([(42, 51), ("foo0", "bar0"), param("foo1", "bar1")])
@@ -196,6 +195,20 @@ class TestParameterizedExpandWithNoMockPatchForClassNoExpand(object):
                              (foo, bar, mock_umask._mock_name))
 
 
+expect("standalone", [
+    "test_mock_patch_standalone_function(42, 'umask')",
+])
+
+@parameterized([(42, )])
+@mock.patch("os.umask")
+def test_mock_patch_standalone_function(foo, mock_umask):
+    missing_tests.remove(
+        "test_mock_patch_standalone_function(%r, %r)" %(
+            foo, mock_umask._mock_name
+        )
+    )
+
+
 class TestParamerizedOnTestCase(TestCase):
     expect([
         "test_on_TestCase('foo0', bar=None)",
@@ -229,6 +242,7 @@ class TestParamerizedOnTestCase(TestCase):
         missing_tests.remove("%s(%r, bar=%r)" %(expected_name, foo, bar))
 
 
+@skipIf(sys.version_info[:2] >= (3, 8), "Doesn't work with Python 3.8")
 class TestParameterizedExpandDocstring(TestCase):
     def _assert_docstring(self, expected_docstring, rstrip=False):
         """ Checks the current test method's docstring. Must be called directly
@@ -237,8 +251,7 @@ class TestParameterizedExpandDocstring(TestCase):
         f_locals = stack[3][0].f_locals
         test_method = (
             f_locals.get("testMethod") or # Py27
-            f_locals.get("function") or # Py33
-            f_locals.get("method") # Py38
+            f_locals.get("function") # Py33
         )
         if test_method is None:
             raise AssertionError("uh oh, unittest changed a local variable name")
@@ -336,7 +349,7 @@ def test_helpful_error_on_empty_iterable_input_expand():
         raise AssertionError("Expected exception not raised")
 
 
-expect("generator", [
+expect("stadalone generator", [
     "test_wrapped_iterable_input('foo')",
 ])
 @parameterized(lambda: iter(["foo"]))
@@ -470,13 +483,35 @@ class TestParameterizedClass(TestCase):
 ])
 class TestParameterizedClassDict(TestCase):
     expect([
+        "TestParameterizedClassDict_0:setUp(1, 0)",
+        "TestParameterizedClassDict_0:tearDown(1, 0)",
         "TestParameterizedClassDict_0:test_method(1, 0)",
         "TestParameterizedClassDict_1:test_method(0, 1)",
+        "TestParameterizedClassDict_1:setUp(0, 1)",
+        "TestParameterizedClassDict_1:tearDown(0, 1)",
     ])
 
     foo = 0
     bar = 0
 
+    def setUp(self):
+        # Ensure that super() works (issue #73)
+        super(TestParameterizedClassDict, self).setUp()
+        missing_tests.remove("%s:setUp(%r, %r)" %(
+            self.__class__.__name__,
+            self.foo,
+            self.bar,
+        ))
+
+    def tearDown(self):
+        # Ensure that super() works (issue #73)
+        super(TestParameterizedClassDict, self).tearDown()
+        missing_tests.remove("%s:tearDown(%r, %r)" %(
+            self.__class__.__name__,
+            self.foo,
+            self.bar,
+        ))
+
     def test_method(self):
         missing_tests.remove("%s:test_method(%r, %r)" %(
             self.__class__.__name__,
